﻿using Microsoft.UI.Xaml.Controls;
using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "TabView 엘리먼트 : XAML로 정의한 TabViewItem 엘리먼트 사용하기";

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 탭뷰 탭 추가 버튼 클릭시 처리하기 - tabView_AddTabButtonClick(tabView, _)

        /// <summary>
        /// 탭뷰 탭 추가 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="tabView">탭뷰</param>
        /// <param name="_">이벤트 인자</param>
        private void tabView_AddTabButtonClick(TabView tabView, object _)
        {
            int index = tabView.TabItems.Count;

            TabViewItem item = GetTabViewItem(index);

            tabView.TabItems.Add(item);
        }

        #endregion
        #region 탭뷰 탭 닫기 요청시 처리하기 - tabView_TabCloseRequested(tabView, e)

        /// <summary>
        /// 탭뷰 탭 닫기 요청시 처리하기
        /// </summary>
        /// <param name="tabView">탭뷰</param>
        /// <param name="e">이벤트 인자</param>
        private void tabView_TabCloseRequested(TabView tabView, TabViewTabCloseRequestedEventArgs e)
        {
            tabView.TabItems.Remove(e.Tab);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 탭뷰 항목 구하기 - GetTabViewItem(index)

        /// <summary>
        /// 탭뷰 항목 구하기
        /// </summary>
        /// <param name="index">인덱스</param>
        /// <returns>탭뷰 항목</returns>
        private TabViewItem GetTabViewItem(int index)
        {
            TabViewItem item = new TabViewItem
            {
                Header     = $"문서 {index}",
                IconSource = new Microsoft.UI.Xaml.Controls.SymbolIconSource() { Symbol = Symbol.Document }
            };

            Frame frame = new Frame();

            switch(index % 3)
            {
                case 0 :

                    frame.Navigate(typeof(SamplePage1));

                    break;

                case 1 :

                    frame.Navigate(typeof(SamplePage2));

                    break;

                case 2 :

                    frame.Navigate(typeof(SamplePage3));

                    break;
            }

            item.Content = frame;

            return item;
        }

        #endregion
    }
}